==> tine20-allinone_2020.03.4.tar.bz2: Setup/js/Setup-lang-es_MX-debug.js <==
/************************** namespace for static data **************************/ 
Tine = window.Tine || {};
Tine.__translationData = Tine.__translationData || {};
Tine.__translationData.msgs = Tine.__translationData.msgs || {};
/********************** tine translations of Setup **********************/ 
Tine.__translationData.msgs['./LC_MESSAGES/Setup'] = ({
""
: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2018-11-28 11:10+0000\nLast-Translator: Christian Feitl <c.feitl@metaways.de>\nLanguage-Team: Spanish (Mexico) (http://www.transifex.com/tine20/tine20/language/es_MX/)\nLanguage: es_MX\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nPlural-Forms: nplurals=2; plural=(n != 1);\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"

, "I have read the license agreement and accept it"
: "He leído el acuerdo de la licenciamiento y lo acepto"

, "License Agreement"
: "Acuerdo de Licenciamiento"

, "I have read the privacy agreement and accept it"
: "He leído el acuerdo de privacidad y lo acepto"

, "Privacy Agreement"
: "Acuerdo de Privacidad"

, "Accept Terms and Conditions"
: "Aceptar Términos y Condiciones"

, "Backend"
: "Administración"

, "Standard IMAP"
: "IMAP estándar"

, "Standard SMTP"
: "SMTP estándar"

, "Imap"
: "IMAP"

, "Hostname"
: "Nombre del Host"

, "Username"
: "Nombre de Usuario"

, "Password"
: "Contraseña"

, "Port"
: "Puerto"

, "Secure Connection"
: "Conexión Segura"

, "None"
: "Ninguno"

, "TLS"
: "TLS"

, "SSL"
: "SSL"

, "Verify peer Certificate"
: ""

, "Use system account"
: "Utiliza cuenta del sistema"

, "No"
: "No"

, "Yes"
: "Si"

, "Append domain to login name"
: "Anexar dominio a nombre de ingreso"

, "Use email address as login name"
: ""

, "Cyrus Admin"
: "Administrador Cyrus"

, "Cyrus Admin Password"
: "Contraseña de Administrador Cyrus"

, "Use proxy auth"
: ""

, "Smtp"
: "SMTP"

, "Authentication"
: "Autentificación"

, "Login"
: "Iniciar Sesión"

, "Plain"
: "Plano"

, "Primary Domain"
: "Dominio Primario"

, "Secondary Domains (comma separated)"
: "Dominios Secundarios (separados por coma)"

, "Notifications service address"
: "Dirección del Servicio de Notificaciones"

, "Notification Username"
: "Nombre de Usuario de Notificaciones"

, "Notification Password"
: "Contraseña de Notificaciones"

, "Notifications local client (hostname or IP address)"
: "Cliente Local de Notificaciones (nombre del host o dirección IP)"

, "SIEVE"
: "SIEVE"

, "MySql Hostname"
: "Nombre del host MySQL"

, "MySql Database"
: "Base de Datos MySQL"

, "MySql User"
: "Usuario de MySQL"

, "MySql Password"
: "Contraseña de MySQL"

, "MySql Port"
: "Puerto de MySQL"

, "User or UID"
: "Usuario o UID"

, "Group or GID"
: "Grupo o GIP"

, "Home Template"
: "Plantilla de Inicio"

, "Password Scheme"
: "Esquema de Contraseñas"

, "PLAIN-MD5"
: "PLAIN-MD5"

, "MD5-CRYPT"
: "MD5-CRYPT"

, "SHA1"
: "SHA1"

, "SHA256"
: "SHA256"

, "SSHA256"
: "SSHA256"

, "SHA512"
: "SHA512"

, "SSHA512"
: "SSHA512"

, "PLAIN"
: "PLAIN"

, "Terms and Conditions"
: "Términos y Condiciones"

, "Setup Checks"
: "Verificaciones de Instalación"

, "Config Manager"
: "Administrador de Configuración"

, "Authentication/Accounts"
: "Autentificación/Cuentas"

, "Email"
: "Email"

, "Application Manager"
: "Administrador de Aplicación"

, "Setup"
: ""

, "Name"
: "Nombre"

, "Enabled"
: "Habilitado"

, "Order"
: "Ordenar"

, "Installed Version"
: "Versión Instalada"

, "Available Version"
: "Versión Disponible"

, "Status"
: "Estatus"

, "Depends on"
: "Depende de"

, "Install application"
: "Instalar aplicación"

, "Uninstall application"
: "Desinstalar aplicación"

, "Update application"
: "Actualizar aplicación"

, "Go to {0} login"
: "Ir al {0} de ingreso"

, "uninstall"
: "desinstalar"

, "Do you really want to uninstall the application(s)?"
: "¿Realmente deseas desinstalar la(s) aplicación(es)?"

, "This may take a while"
: "Esto puede tomar algo de tiempo"

, "Dependency Violation"
: "Violación de Dependencia"

, "CLI Required"
: ""

, "Delete all existing users and groups"
: "Borrar todos los usuarios y grupos existentes"

, "Switching from SQL to LDAP will delete all existing User Accounts, Groups and Roles. Do you really want to switch the accounts storage backend to LDAP ?"
: "Cambiar de SQL a LDAP borrará todas las Cuentas de Usuario, Grupos y Roles. ¿Realmente deseas cambiar la administración de almacenamiento de cuentas a LDAP?"

, "TLS client certificate"
: ""

, "Initial Admin User"
: "Usuario inicial de administrador"

, "Initial admin login name"
: "Nombre inicial de ingreso de administrador"

, "Initial admin Password"
: "Contraseña inicial de administrador"

, "Password confirmation"
: "Confirmación de Contraseña"

, "Authentication provider"
: "Proveedor de autentificación"

, "Try to split username"
: "Intenta dividir el nombre de usuario"

, "Account canonical form"
: "Forma canónica de la cuenta"

, "Account domain name"
: ""

, "Account domain short name"
: "Nombre corto de dominio de la cuenta"

, "Host"
: "Host"

, "Login name"
: "Nombre de ingreso"

, "Bind requires DN"
: "Bind requiere DN"

, "Start TLS"
: ""

, "Base DN"
: "Base DN"

, "Search filter"
: "Filtro de búsqueda"

, "Certificate validation"
: ""

, "CA file"
: ""

, "CRL directory"
: ""

, "Accounts storage"
: "Almacenamiento de cuentas"

, "Default user group name"
: "Nombre predeterminado de grupo de usuarios"

, "Default admin group name"
: "Nombre predeterminado de grupo de administradores"

, "Login panel"
: ""

, "Reuse last username logged"
: ""

, "Password Settings"
: ""

, "User can change password"
: "Usuario puede cambiar contraseña"

, "Enable password policy"
: ""

, "Only ASCII"
: ""

, "Minimum length"
: ""

, "Minimum word chars"
: ""

, "Minimum uppercase chars"
: ""

, "Minimum special chars"
: ""

, "Minimum numbers"
: ""

, "Change password after ... days"
: ""

, "Forbid part of username in password"
: ""

, "Redirect Settings"
: "Configuración de Redirección"

, "Redirect Url (redirect to login screen if empty)"
: "Redireccionar URL (redireccionar a pantalla de inicio de sesión si está vacio)"

, "Redirect Always (if No, only redirect after logout)"
: "Redireccionar Siempre (si No, únicamente redireccionar después de cerrar sesión)"

, "Redirect to referring site, if exists"
: "Redireccionar a sitio de referencia, si existe"

, "Password encoding"
: "Codificación de contraseña"

, "des"
: ""

, "crypt"
: ""

, "blowfish_crypt"
: ""

, "md5_crypt"
: ""

, "ext_crypt"
: ""

, "md5"
: ""

, "smd5"
: ""

, "sha"
: ""

, "ssha"
: ""

, "ntpassword"
: ""

, "plain"
: ""

, "User DN"
: "Usuario DN"

, "User Filter"
: "Filtro de Usuarios"

, "User Search Scope"
: "Ámbito de Búsqueda de Usuario"

, "Groups DN"
: "Grupos DN"

, "Group Filter"
: "Filtro de Grupos"

, "Group Search Scope"
: "Ámbito de Búsqueda de Grupos"

, "Use Rfc 2307 bis"
: "Usar RFC 2037 bits"

, "Maintain RFC 2307 attributes"
: ""

, "Min User Id"
: "ID Mínimo de Usuario"

, "Max User Id"
: "ID Máximo de Usuario"

, "Min Group Id"
: "ID Mínimo de Grupo"

, "Max Group Id"
: "ID Máximo de Grupo"

, "Group UUID Attribute name"
: "Nombre del Atributo del Grupo UUID"

, "User UUID Attribute name"
: "Nombre del Atributo del Usuario UUID"

, "Readonly access"
: "Acceso de solo lectura"

, "Save config and install"
: "Guardar configuración e instalar"

, "Save config"
: "Guardar configuración"

, "Passwords don't match"
: "Las contraseñas no coinciden"

, "Should not be empty"
: "No debería estar vacío"

, "Performing Environment Checks..."
: "Realizando Comprobaciones de Ambiente..."

, "There could not be found any {0}. Please try to change your filter-criteria, view-options or the {1} you search in."
: ""

, "Check"
: "Verificar"

, "Result"
: "Resultado"

, "Error"
: "Error"

, "Run setup tests"
: "Realizar pruebas de instalación"

, "Ignore setup tests"
: "Ignorar pruebas de instalación"

, "Application, Applications"
: [
  "Aplicación"
 ,"Aplicaciones"

]
, "File"
: "Archivo"

, "Setup Authentication"
: "Autentificación del Instalador"

, "Database"
: "Base de Datos"

, "User"
: "Usuario"

, "Prefix"
: "Prefijo"

, "Logging"
: "Registro de Eventos"

, "Filename"
: "Nombre de Archivo"

, "Priority"
: "Prioridad"

, "Caching"
: "Cacheo"

, "Lifetime (seconds)"
: "Tiempo de Vida (segundos)"

, "Path"
: "Ruta"

, "Queue"
: ""

, "Session"
: "Sesión"

, "Temporary files"
: "Archivos Temporales"

, "Temporary Files Path"
: "Ruta de Archivos Temporales"

, "Filestore directory"
: "Directorio de Almacenamiento de Archivos"

, "Filestore Path"
: "Ruta de Almacenamiento de Archivos"

, "Addressbook Map panel"
: "Panel de Mapa de Directorio"

, "Map panel"
: "Panel de Mapa"

, "disabled"
: "deshabilitado"

, "enabled"
: "habilitado"

, "Config file is not writable"
: "El archivo de configuración no tiene permisos de escritura"

, "Download config file"
: "Descargar archivo de configuración"

, "This prefix is too long. Please choose a prefix no longer than {0} chars."
: ""

, "Application"
: "Aplicación"

}); 
/********************** translation loaded flag **********************/ 
Tine.__translationData.__isLoaded = true;

==> tine20-allinone_2021.12.1.tar.bz2: Setup/js/Setup-lang-es_MX-debug.js <==
/************************** namespace for static data **************************/ 
Tine = window.Tine || {};
Tine.__translationData = Tine.__translationData || {};
Tine.__translationData.msgs = Tine.__translationData.msgs || {};
/********************** tine translations of Setup **********************/ 
Tine.__translationData.msgs['./LC_MESSAGES/Setup'] = ({
""
: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2020-05-11 11:59+0000\nLast-Translator: Christian Feitl <c.feitl@metaways.de>\nLanguage-Team: Spanish (Mexico) (http://www.transifex.com/tine20/tine20/language/es_MX/)\nLanguage: es_MX\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nPlural-Forms: nplurals=2; plural=(n != 1);\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"

, "Performing Environment Checks..."
: "Realizando Comprobaciones de Ambiente..."

, "There could not be found any {0}. Please try to change your filter-criteria, view-options or the {1} you search in."
: ""

, "Check"
: "Verificar"

, "Result"
: "Resultado"

, "Message"
: ""

, "Run setup tests"
: "Realizar pruebas de instalación"

, "Ignore setup tests"
: "Ignorar pruebas de instalación"

, "Install application"
: "Instalar aplicación"

, "Name"
: "Nombre"

, "Enabled"
: "Habilitado"

, "Order"
: "Ordenar"

, "Installed Version"
: "Versión Instalada"

, "Available Version"
: "Versión Disponible"

, "Status"
: "Estatus"

, "Depends on"
: "Depende de"

, "Uninstall application"
: "Desinstalar aplicación"

, "Update applications"
: ""

, "Go to {0} login"
: "Ir al {0} de ingreso"

, "uninstall"
: "desinstalar"

, "Do you really want to uninstall the application(s)?"
: "¿Realmente deseas desinstalar la(s) aplicación(es)?"

, "This may take a while"
: "Esto puede tomar algo de tiempo"

, "Dependency Violation"
: "Violación de Dependencia"

, "CLI Required"
: ""

, "Delete all existing users and groups"
: "Borrar todos los usuarios y grupos existentes"

, "Switching from SQL to LDAP will delete all existing User Accounts, Groups and Roles. Do you really want to switch the accounts storage backend to LDAP ?"
: "Cambiar de SQL a LDAP borrará todas las Cuentas de Usuario, Grupos y Roles. ¿Realmente deseas cambiar la administración de almacenamiento de cuentas a LDAP?"

, "Backend"
: "Administración"

, "TLS client certificate"
: ""

, "Initial Admin User"
: "Usuario inicial de administrador"

, "Initial admin login name"
: "Nombre inicial de ingreso de administrador"

, "Initial admin Password"
: "Contraseña inicial de administrador"

, "Password confirmation"
: "Confirmación de Contraseña"

, "Authentication provider"
: "Proveedor de autentificación"

, "Try to split username"
: "Intenta dividir el nombre de usuario"

, "Yes"
: "Si"

, "No"
: "No"

, "Account canonical form"
: "Forma canónica de la cuenta"

, "Account domain name"
: ""

, "Account domain short name"
: "Nombre corto de dominio de la cuenta"

, "Host"
: "Host"

, "Login name"
: "Nombre de ingreso"

, "Password"
: "Contraseña"

, "Bind requires DN"
: "Bind requiere DN"

, "Start TLS"
: ""

, "SSL"
: "SSL"

, "Port"
: "Puerto"

, "Base DN"
: "Base DN"

, "Search filter"
: "Filtro de búsqueda"

, "Hostname"
: "Nombre del Host"

, "Secure Connection"
: "Conexión Segura"

, "None"
: "Ninguno"

, "TLS"
: "TLS"

, "Append domain to login name"
: "Anexar dominio a nombre de ingreso"

, "Certificate validation"
: ""

, "CA file"
: ""

, "CRL directory"
: ""

, "Accounts storage"
: "Almacenamiento de cuentas"

, "Default user group name"
: "Nombre predeterminado de grupo de usuarios"

, "Default admin group name"
: "Nombre predeterminado de grupo de administradores"

, "Login panel"
: ""

, "Reuse last username logged"
: ""

, "Password Settings"
: ""

, "User can change password"
: "Usuario puede cambiar contraseña"

, "Enable password policy"
: ""

, "Only ASCII"
: ""

, "Minimum length"
: ""

, "Minimum word chars"
: ""

, "Minimum uppercase chars"
: ""

, "Minimum special chars"
: ""

, "Minimum numbers"
: ""

, "Change password after ... days"
: ""

, "Forbid part of username in password"
: ""

, "Redirect Settings"
: "Configuración de Redirección"

, "Redirect Url (redirect to login screen if empty)"
: "Redireccionar URL (redireccionar a pantalla de inicio de sesión si está vacio)"

, "Redirect Always (if No, only redirect after logout)"
: "Redireccionar Siempre (si No, únicamente redireccionar después de cerrar sesión)"

, "Redirect to referring site, if exists"
: "Redireccionar a sitio de referencia, si existe"

, "Password encoding"
: "Codificación de contraseña"

, "des"
: ""

, "crypt"
: ""

, "blowfish_crypt"
: ""

, "md5_crypt"
: ""

, "ext_crypt"
: ""

, "md5"
: ""

, "smd5"
: ""

, "sha"
: ""

, "ssha"
: ""

, "ntpassword"
: ""

, "plain"
: ""

, "User DN"
: "Usuario DN"

, "User Filter"
: "Filtro de Usuarios"

, "User Search Scope"
: "Ámbito de Búsqueda de Usuario"

, "Groups DN"
: "Grupos DN"

, "Group Filter"
: "Filtro de Grupos"

, "Group Search Scope"
: "Ámbito de Búsqueda de Grupos"

, "Use Rfc 2307 bis"
: "Usar RFC 2037 bits"

, "Maintain RFC 2307 attributes"
: ""

, "Min User Id"
: "ID Mínimo de Usuario"

, "Max User Id"
: "ID Máximo de Usuario"

, "Min Group Id"
: "ID Mínimo de Grupo"

, "Max Group Id"
: "ID Máximo de Grupo"

, "Group UUID Attribute name"
: "Nombre del Atributo del Grupo UUID"

, "User UUID Attribute name"
: "Nombre del Atributo del Usuario UUID"

, "Readonly access"
: "Acceso de solo lectura"

, "Save config and install"
: "Guardar configuración e instalar"

, "Save config"
: "Guardar configuración"

, "Passwords don't match"
: "Las contraseñas no coinciden"

, "Should not be empty"
: "No debería estar vacío"

, "File"
: "Archivo"

, "Setup Authentication"
: "Autentificación del Instalador"

, "Username"
: "Nombre de Usuario"

, "Database"
: "Base de Datos"

, "User"
: "Usuario"

, "Prefix"
: "Prefijo"

, "Logging"
: "Registro de Eventos"

, "Filename"
: "Nombre de Archivo"

, "Priority"
: "Prioridad"

, "Caching"
: "Cacheo"

, "Lifetime (seconds)"
: "Tiempo de Vida (segundos)"

, "Path"
: "Ruta"

, "Queue"
: ""

, "Session"
: "Sesión"

, "Temporary files"
: "Archivos Temporales"

, "Temporary Files Path"
: "Ruta de Archivos Temporales"

, "Filestore directory"
: "Directorio de Almacenamiento de Archivos"

, "Filestore Path"
: "Ruta de Almacenamiento de Archivos"

, "Addressbook Map panel"
: "Panel de Mapa de Directorio"

, "Map panel"
: "Panel de Mapa"

, "disabled"
: "deshabilitado"

, "enabled"
: "habilitado"

, "Config file is not writable"
: "El archivo de configuración no tiene permisos de escritura"

, "Download config file"
: "Descargar archivo de configuración"

, "This prefix is too long. Please choose a prefix no longer than {0} chars."
: ""

, "Standard IMAP"
: "IMAP estándar"

, "Standard SMTP"
: "SMTP estándar"

, "Imap"
: "IMAP"

, "Verify peer Certificate"
: ""

, "Use system account"
: "Utiliza cuenta del sistema"

, "Use email address as login name"
: ""

, "Cyrus Admin"
: "Administrador Cyrus"

, "Cyrus Admin Password"
: "Contraseña de Administrador Cyrus"

, "Use proxy auth"
: ""

, "Smtp"
: "SMTP"

, "Authentication"
: "Autentificación"

, "Login"
: "Iniciar Sesión"

, "Plain"
: "Plano"

, "Primary Domain"
: "Dominio Primario"

, "Secondary Domains (comma separated)"
: "Dominios Secundarios (separados por coma)"

, "Notifications service address"
: "Dirección del Servicio de Notificaciones"

, "Notification Username"
: "Nombre de Usuario de Notificaciones"

, "Notification Password"
: "Contraseña de Notificaciones"

, "Notifications local client (hostname or IP address)"
: "Cliente Local de Notificaciones (nombre del host o dirección IP)"

, "SIEVE"
: "SIEVE"

, "MySql Hostname"
: "Nombre del host MySQL"

, "MySql Database"
: "Base de Datos MySQL"

, "MySql User"
: "Usuario de MySQL"

, "MySql Password"
: "Contraseña de MySQL"

, "MySql Port"
: "Puerto de MySQL"

, "User or UID"
: "Usuario o UID"

, "Group or GID"
: "Grupo o GIP"

, "Home Template"
: "Plantilla de Inicio"

, "Password Scheme"
: "Esquema de Contraseñas"

, "PLAIN-MD5"
: "PLAIN-MD5"

, "MD5-CRYPT"
: "MD5-CRYPT"

, "SHA1"
: "SHA1"

, "SHA256"
: "SHA256"

, "SSHA256"
: "SSHA256"

, "SHA512"
: "SHA512"

, "SSHA512"
: "SSHA512"

, "PLAIN"
: "PLAIN"

, "Setup"
: ""

, "Application, Applications"
: [
  "Aplicación"
 ,"Aplicaciones"

]
, "Terms and Conditions"
: "Términos y Condiciones"

, "Setup Checks"
: "Verificaciones de Instalación"

, "Config Manager"
: "Administrador de Configuración"

, "Authentication/Accounts"
: "Autentificación/Cuentas"

, "Email"
: "Email"

, "Application Manager"
: "Administrador de Aplicación"

, "I have read the license agreement and accept it"
: "He leído el acuerdo de la licenciamiento y lo acepto"

, "License Agreement"
: "Acuerdo de Licenciamiento"

, "I have read the privacy agreement and accept it"
: "He leído el acuerdo de privacidad y lo acepto"

, "Privacy Agreement"
: "Acuerdo de Privacidad"

, "Accept Terms and Conditions"
: "Aceptar Términos y Condiciones"


, "Application"
: "Aplicación"

}); 
/********************** translation loaded flag **********************/ 
Tine.__translationData.__isLoaded = true;
